pub struct AggregateConfigWrapped {
pub inputs: Vec<String>,
pub error_policy: ErrorPolicy,
pub config: AggregateConfig,
}Expand description
Wrapper for generic SQL aggregate transform with common pipeline fields.
Fields
inputs: Vec<String>List of upstream component names to receive events from.
error_policy: ErrorPolicyPolicy for handling events that cause errors during aggregation.
config: AggregateConfigSQL aggregation-specific configuration.
Implementations
Sourceimpl AggregateConfigWrapped
impl AggregateConfigWrapped
pub fn component_metadata() -> ComponentMetadata