pub struct DlqSinkConfigWrapped {
pub inputs: Vec<String>,
pub error_policy: ErrorPolicy,
pub encoding: Option<EncoderConfigEnum>,
pub buffer: BufferConfig,
pub config: DlqSinkConfig,
}Expand description
Dead letter queue sink that writes failed events to S3.
Fields
inputs: Vec<String>Upstream component names that feed events into this sink.
error_policy: ErrorPolicyPolicy for handling errors during event processing.
encoding: Option<EncoderConfigEnum>Optional encoder configuration for output events.
buffer: BufferConfigBuffer configuration for event batching.
config: DlqSinkConfigInner DLQ-specific sink configuration.
Implementations
Sourceimpl DlqSinkConfigWrapped
impl DlqSinkConfigWrapped
pub fn component_metadata() -> ComponentMetadata