pub struct FilterConfig {
pub inputs: Vec<String>,
pub condition: FilterCondition,
pub error_policy: ErrorPolicy,
}Expand description
Filters events based on a condition, either passing or dropping matches.
Fields
inputs: Vec<String>List of upstream component names to receive events from.
condition: FilterConditionThe filter condition to evaluate against each event.
error_policy: ErrorPolicyPolicy for handling events that cause errors during filtering.
Implementations
Sourceimpl FilterConfig
impl FilterConfig
pub fn component_metadata() -> ComponentMetadata