pub struct IcebergSinkConfigWrapped {
pub inputs: Vec<String>,
pub error_policy: ErrorPolicy,
pub encoding: Option<EncoderConfigEnum>,
pub buffer: BufferConfig,
pub catalog_endpoint: String,
pub table: String,
pub warehouse: String,
pub max_rows: u64,
pub max_bytes: u64,
pub max_age_ms: u64,
}Expand description
Writes events to Apache Iceberg tables.
Fields
inputs: Vec<String>Upstream component names that feed events into this sink.
error_policy: ErrorPolicyPolicy for handling errors during event processing.
encoding: Option<EncoderConfigEnum>Optional encoder configuration for output events.
buffer: BufferConfigBuffer configuration for event batching.
catalog_endpoint: StringIceberg catalog endpoint URL.
table: StringFully qualified Iceberg table name (e.g., ‘db.table’).
warehouse: StringBase URI for the Iceberg warehouse storage.
max_rows: u64Maximum number of rows per batch before flushing.
max_bytes: u64Maximum byte size of a batch before flushing.
max_age_ms: u64Maximum age of a batch in milliseconds before flushing.
Implementations
Sourceimpl IcebergSinkConfigWrapped
impl IcebergSinkConfigWrapped
pub fn component_metadata() -> ComponentMetadata